@@ -5,6 +5,7 @@
 #' \itemize{
 #'   \item{param [\code{list}]}{Named list of parameter value(s).}
 #'   \item{value [\code{numeric(1)}]}{Optimal value.}
+#'   \item{is.minimum [\code{logical(1)}]}{Is the global optimum a minimum or maximum?}
 #' }
 #' @note Keep in mind, that this method makes sense only for single-objective target function.
 #' @export
@@ -16,7 +17,8 @@ getGlobalOptimum = function(fn) {
 getGlobalOptimum.smoof_single_objective_function = function(fn) {
   return(list(
     param = attr(fn, "global.opt.params"),
-    value = attr(fn, "global.opt.value")
+    value = attr(fn, "global.opt.value"),
+    is.minimum = attr(fn, "minimize")
   ))
 }
 
