@@ -22,7 +22,7 @@ makeZDT1Function = function(dimensions) {
 
   # define the two-objective ZDT1 function
   fn = function(x) {
-    stopifnot(length(x) == dimensions)
+    assertNumeric(x, len = dimensions, any.missing = FALSE, all.missing = FALSE)
     n = length(x)
     f1 = x[1]
     g = 1 + 9 * sum(x[2:n]) / (n - 1)
@@ -33,6 +33,7 @@ makeZDT1Function = function(dimensions) {
 
   makeMultiObjectiveFunction(
     name = "ZDT1 Function",
+    id = paste0("zdt1_", dimensions, "d_2o"),
     description = "Zitzler et al. function N. 1",
     fn = fn,
     par.set =  makeNumericParamSet(
@@ -47,6 +48,6 @@ makeZDT1Function = function(dimensions) {
 }
 
 class(makeZDT1Function) = c("function", "smoof_generator")
-attr(makeZDT1Function, "name") = c("ZDT1 Function")
+attr(makeZDT1Function, "name") = c("ZDT1")
 attr(makeZDT1Function, "type") = c("multi-objective")
-attr(makeZDT1Function, "tags") = c()
+attr(makeZDT1Function, "tags") = c("multi-objective")
