@@ -23,8 +23,10 @@ makeMichalewiczFunction = function(dimensions, m = 10) {
   assertNumber(m, na.ok = FALSE)
   force(m)
   makeSingleObjectiveFunction(
-    name = paste("Michalewicz Function (m = ", m, ")", sep = ""),
+    name = paste(dimensions, "-d Michalewicz Function (m = ", m, ")", sep = ""),
+    id = paste0("michalewicz_", dimensions, "d_m", m),
     fn = function(x) {
+      assertNumeric(x, len = 2L, any.missing = FALSE, all.missing = FALSE)
       i = 1:length(x)
       (-1) * sum(sin(x) * (sin((i * x^2) / pi)^(2 * m)))
     },
@@ -42,9 +44,9 @@ makeMichalewiczFunction = function(dimensions, m = 10) {
 }
 
 class(makeMichalewiczFunction) = c("function", "smoof_generator")
-attr(makeMichalewiczFunction, "name") = c("Michalewicz Function")
+attr(makeMichalewiczFunction, "name") = c("Michalewicz")
 attr(makeMichalewiczFunction, "type") = c("single-objective")
-attr(makeMichalewiczFunction, "tags") = c("continuous", "multimodal", "scalable")
+attr(makeMichalewiczFunction, "tags") = c("single-objective", "continuous", "multimodal", "scalable")
 
 # Helper to determine global optimum based on dimension and m parameter.
 getMichalewiczGlobalOptimum = function(dimensions = 2L, m = 10) {
