@@ -14,7 +14,9 @@
 makePriceN4Function = function() {
   makeSingleObjectiveFunction(
     name = "Price Function N. 4",
+    id = "price04_2d",
     fn = function(x) {
+      assertNumeric(x, len = 2L, any.missing = FALSE, all.missing = FALSE)
       (2 * x[1]^3 * x[2] - x[2]^3)^2 + (6 * x[1] - x[2]^2 + x[2])^2
     },
     par.set = makeNumericParamSet(
@@ -37,4 +39,4 @@ makePriceN4Function = function() {
 class(makePriceN4Function) = c("function", "smoof_generator")
 attr(makePriceN4Function, "name") = c("Price Function N. 4")
 attr(makePriceN4Function, "type") = c("single-objective")
-attr(makePriceN4Function, "tags") = c("continuous", "differentiable", "non-separable", "non-scalable", "multimodal")
+attr(makePriceN4Function, "tags") = c("single-objective", "continuous", "differentiable", "non-separable", "non-scalable", "multimodal")
