@@ -4,7 +4,7 @@ test_that("hasTags works as expected", {
   # check that hasTags works for smoof_functions
   fun.names = as.list(filterFunctionsByTags(c("multimodal")))
   funs = unlist(lapply(fun.names, function(fun.name) {
-    makeFunctionByName(fun.name, dimensions = 2L)
+    makeFunctionsByName(fun.name, dimensions = 2L)
   }))
 
   for (fun in funs) {
@@ -17,6 +17,6 @@ test_that("hasTags works as expected", {
   expect_false(hasTags(makeSphereFunction, "multimodal"))
 
   # check that hasTags works for strings
-  expect_true(hasTags("Ackley Function", "multimodal"))
-  expect_false(hasTags("Sphere Function", "multimodal"))
+  expect_true(hasTags("Ackley", "multimodal"))
+  expect_false(hasTags("Sphere", "multimodal"))
 })
